Welcome to taperable_helix's documentation!
============================================

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   contributing
   authors
   history

.. toctree::
   :hidden:

   taperable_helix

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
